"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useEndpoint = exports.getClusterAndEndpoint = void 0;
const react_1 = require("@strata-foundation/react");
const components_1 = require("../components");
const wallet_adapter_base_1 = require("@solana/wallet-adapter-base");
const web3_js_1 = require("@solana/web3.js");
const react_2 = require("react");
const shortnames = new Set([
    "localnet",
    ...Object.values(wallet_adapter_base_1.WalletAdapterNetwork).map((v) => v.toString()),
]);
function getClusterAndEndpoint(clusterOrEndpoint) {
    if (clusterOrEndpoint) {
        if (clusterOrEndpoint.startsWith("http")) {
            if (clusterOrEndpoint.includes("dev")) {
                return { cluster: "devnet", endpoint: clusterOrEndpoint };
            }
            else {
                return { cluster: "mainnet-beta", endpoint: clusterOrEndpoint };
            }
        }
        else if (shortnames.has(clusterOrEndpoint)) {
            if (clusterOrEndpoint === "localnet") {
                return {
                    cluster: "localnet",
                    endpoint: (0, web3_js_1.clusterApiUrl)(clusterOrEndpoint),
                };
            }
            else if (clusterOrEndpoint === "devnet") {
                return {
                    cluster: "devnet",
                    endpoint: "https://devnet.genesysgo.net/",
                };
            }
            else if (clusterOrEndpoint === "mainnet-beta") {
                return {
                    cluster: "mainnet-beta",
                    endpoint: "https://strataprotocol.genesysgo.net",
                };
            }
            return {
                cluster: clusterOrEndpoint,
                endpoint: "http://localhost:8899",
            };
        }
    }
    return { cluster: "mainnet-beta", endpoint: components_1.DEFAULT_ENDPOINT };
}
exports.getClusterAndEndpoint = getClusterAndEndpoint;
function useEndpoint() {
    const [clusterOrEndpoint, setCluster] = (0, react_1.useQueryString)("cluster", components_1.DEFAULT_ENDPOINT);
    const { cluster: actualCluster, endpoint } = (0, react_2.useMemo)(() => getClusterAndEndpoint(clusterOrEndpoint), [clusterOrEndpoint]);
    return {
        cluster: actualCluster,
        endpoint,
        setClusterOrEndpoint: setCluster,
    };
}
exports.useEndpoint = useEndpoint;
//# sourceMappingURL=useEndpoint.js.map